#include <sys/types.h>
#include <sys/stream.h>

#include <config.h>
#include <sys/nopconfig.h>

/**************************************************************************************

This file is installed in ....conf/pack.d/space.c It allows values set in the
Master (Mdevice.d) and System (Sdevice.d) to be passed into the driver. To access
these used the following DEFINES:

	  Per module #defines:
	  ---------------------------------------------------------------
	  #define  PRFX		 Set to	1 if module is configured
	  #define  PRFX_CNTLS	 Number	of configured entries in System	file
	  #define  PRFX_UNITS	 Number	of subdevices (sum of unit fields)
	  #define  PRFX_CMAJORS	 Number	of character major numbers supported
	  #define  PRFX_CMAJOR_O Character major numbers supported; the	first
				       major is	PRFX_CMAJOR_0, the second
				       PRFX_CMAJOR_1, and so forth

	  Per instance #defines	(PRFX_0	represents the first configured
	  instance, followed by	PRFX_1,	and so on if more than one
	  instance is configured):
	  ----------------------------------------------------------------
	  #define  PRFX_0	 Unit field value
	  #define  PRFX_0_VECT	 Interrupt vector used
	  #define  PRFX_0_TYPE	 Interrupt vector type
	  #define  PRFX_0_IPL	 Interrupt priority level
	  #define  PRFX_0_SIOA	 Starting input/output address
	  #define  PRFX_0_EIOA	 Ending	input/output address
	  #define  PRFX_0_SCMA	 Starting controller memory address
	  #define  PRFX_0_ECMA	 Ending	controller memory address
	  #define  PRFX_0_CHAN	 DMA channel used (-1 if none)

     NOTES
	  The following	two #defines are generated for the Space.c
	  file only if their values are	identical for all instances:

	  #define  PRFX_CHAN	 DMA channel used (-1 if none)
	  #define  PRFX_TYPE	 Interrupt vector type used

**************************************************************************************/
/*
 *  The STREAMS_LOG define determines if STREAMS tracing will be done in the
 *  driver.  A non-zero value will allow the strace(1M) command to follow
 *  activity in the driver.  The driver ID used in the strace(1M) command is
 *  equal to the ENET_ID value (generally 2101).
 *
 *  NOTE:  STREAMS tracing can greatly reduce the performance of the driver
 *         and should only be used for trouble shooting.
 *
 *  To trace this driver:
 *
 *  1: Compile with NOP_LOG defined
 *  2: Set STREAMS_LOG (below) to 1
 *  3: Do an idbuild -M nop
 *  4: run the strace(1M) command, while using driver
 *
 */
#define	STREAMS_LOG	1

/********************** STOP!  DON'T TOUCH THAT DIAL ************************
 *
 *  The following values are set by the kernel build utilities and should not
 *  be modified by mere motals.
 */
int		nopboards 	= NOP_CNTLS;
int		nopstrlog 	= STREAMS_LOG;

nop_bdconfig_t	nopconfig[ NOP_CNTLS ] = 
{
#ifdef NOP_0
	{
		NOP_CMAJOR_0,		/* Major number			*/
		NOP_0_SIOA,		/* Start of base I/O address	*/
		NOP_0_EIOA,		/* End of base I/O address	*/
		NOP_0_SCMA,		/* Start of base memory address	*/
		NOP_0_ECMA,		/* End of base memory address	*/
		NOP_0_VECT,		/* Interrupt vector number	*/
		0,
	},
#endif
#ifdef NOP_1
	{
		NOP_CMAJOR_1,		/* Major number			*/
		NOP_1_SIOA,		/* Start of base I/O address	*/
		NOP_1_EIOA,		/* End of base I/O address	*/
		NOP_1_SCMA,		/* Start of base memory address	*/
		NOP_1_ECMA,		/* End of base memory address	*/
		NOP_1_VECT,		/* Interrupt vector number	*/
		0,
	},
#endif
#ifdef NOP_2
	{
		NOP_CMAJOR_2,		/* Major number			*/
		NOP_2_SIOA,		/* Start of base I/O address	*/
		NOP_2_EIOA,		/* End of base I/O address	*/
		NOP_2_SCMA,		/* Start of base memory address	*/
		NOP_2_ECMA,		/* End of base memory address	*/
		NOP_2_VECT,		/* Interrupt vector number	*/
		0,
	},
#endif
#ifdef NOP_3
	{
		NOP_CMAJOR_3,		/* Major number			*/
		NOP_3_SIOA,		/* Start of base I/O address	*/
		NOP_3_EIOA,		/* End of base I/O address	*/
		NOP_3_SCMA,		/* Start of base memory address	*/
		NOP_3_ECMA,		/* End of base memory address	*/
		NOP_3_VECT,		/* Interrupt vector number	*/
		0,
	},
#endif
};

