/*
 * This is the  STREAMS device driver for NOP.
 *
 * Here we assume there is a NOP device (no-Operation) which
 * has a controller board which interrupts.
 *
 * 1: NOP is just the device driver, not a stream module.
 *
 * 2: Three files:
 *    nopstream.c - This file contains just STREAM routines
 *    nopinit.c   - The initalise and load/unload code
 *    nophrdw.c   - Hardware related code. In particular the interrupts
 */

#include <nop.h>


STATIC char	nopcopyright[]  = "Does nothing at all";
STATIC char	elmcid_string[] = "NOP Driver";
STATIC char	elmccopyright[] = "Copyright (c) 1993 Graeme Vetterlein";

#define DRVNAME		"nop - Loadable nop driver"

STATIC	int	nop_load();
STATIC	int	nop_unload();

MOD_DRV_WRAPPER(nop, nop_load, nop_unload, NULL, DRVNAME);

/*
 * Wrapper functions.
 *
 * nop_load    - Called when a driver is dynamicly loaded
 * nop_unload  - Called when a driver is dynamicly unloaded
 *
 *
 *
 *
 */

STATIC int nopinit();
STATIC void nopuninit();


STATIC int
nop_load(void)
{
  int ret_code;

  DEBUG_ENTER("nop_load", ("(void)"));

  if ((ret_code = nopinit()) != 0)  
    {
    nopuninit();
    return(ret_code);
    }
  mod_drvattach(&nop_attach_info);

  DEBUG_INT_RETURN(0);
}

STATIC int
nop_unload(void)
{

  DEBUG_ENTER("nop_unload", ("(void)"));

  mod_drvdetach(&nop_attach_info);
  nopuninit();

  DEBUG_INT_RETURN(0);
}

/*
 * nopinit ()
 */

int
nopinit ()
{
  unsigned int	bus_p;
  int		ret_code=0;

  DEBUG_ENTER("nopinit", ("(void)"));

  if ((drv_gethardware(IOBUS_TYPE, &bus_p)) < 0) 
    {
    cmn_err(CE_WARN,"nop: can't decide bus type");
    return (2);
    }
  if (bus_p & BUS_MCA) 
    {
    cmn_err (CE_CONT, "%s\n", elmcid_string);
    cmn_err (CE_CONT, "%s\n", elmccopyright);
    cmn_err (CE_CONT, "%s\n", nopcopyright);
    }
  else
    cmn_err (CE_CONT, "%s %s\n", nopid_string, nopcopyright);

  /*  ......*/

  DEBUG_INT_RETURN(ret_code);
}

STATIC void
nopuninit()
{
  DEBUG_ENTER("nopuninit", ("(void)"));

  untimeout (noptimer_id);
  cmn_err (CE_CONT, "%s %s\n", nopid_string, "Disabled");

  DEBUG_VOID_RETURN;
}
